# recruitploteasy

Author: Kenji Gerhardt
Email: Kenji.Gerhardt@gmail.com
Github: https://github.com/KGerhardt/RecruitPlotEasy


RecruitPlotEasy is a tool written in both R and Python 3 that allows for the interactive visualization of short read mapping data.

By supplying a set of genomes in FASTA format and a set of reads mapped to those genomes in tabular BLAST, SAM, or BAM format, a user
can produce Recruitment Plots which display depth of coverage across the genome, percent identity to the reference genome used in 
mapping, and help identify mixed or sequence-discrete populations in a metagenomic sample.

